cli

package
v0.4.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2026 License: GPL-2.0, GPL-2.0-only Imports: 35 Imported by: 0

Documentation

Overview

Package cli provides the command-line interface implementation for crypto-finder.

Index

Constants

This section is empty.

Variables

var AllowedFindingsCacheBackends = []string{findingsCacheBackendDisk, findingsCacheBackendPostgres}

AllowedFindingsCacheBackends lists the FindingsCache backends supported by the tool.

AllowedScanners lists the scanners supported by the tool. TODO: We'll support more scanners in the future (e.g., cbom-toolkit).

var SupportedFormats = []string{formatJSON, "cyclonedx"}

SupportedFormats lists the output formats supported by the tool.

Functions

func Execute

func Execute()

Execute runs the root command and exits on error.

Types

This section is empty.

Jump to